@@ -8,13 +8,15 @@ import sys
 import time
 from pyprind.prog_class import Prog
 
+
 class ProgPercent(Prog):
     """Initializes a percentage indicator object that allows visuzalization
        of an iterational computation in the standard output screen. 
 
     Keyword Arguments:
         iterations (int): number of iterations of the computation
-        track_time (bool): prints elapsed time
+        width (int): width of the progress bar in characters
+        track_time (bool): prints elapsed time and estimated time left
         stream: takes 1 for stdout, 2 for stderr, or given stream object
 
     """
@@ -32,8 +34,9 @@ class ProgPercent(Prog):
         """Prints formatted integer percentage and tracked time to the screen."""
         self._stream_out('\r[%3d %%]' % (self.perc))
         if self.track:
-            self.time[1] = time.clock()
-            self._stream_out('   elapsed: %.3f sec' % self.time[1])
+            self._stream_out('   elapsed: %.3f sec' % self._elapsed())
+            if self._calc_eta():
+                self._stream_out(' | eta: %.3f sec' % self._calc_eta())
             self._stream_flush()
 
     def update(self):
@@ -45,5 +48,6 @@ class ProgPercent(Prog):
             self._print_update()
             self._stream_flush()
         if self.cnt == self.max_iter:
+            if self.track:
+                self._stream_out(' | eta: 0.000 sec')
             self._stream_out('\n') 
- 
